CacheStorageServiceHiveImpl class

Inheritance

Constructors

CacheStorageServiceHiveImpl({required SharedPreferences prefs})

Properties

hashCode int
The hash code for this object.
no setterinherited
prefs → SharedPreferences
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearMemory() Future<bool>
override
containsKey(String key) bool
override
get(String key) → dynamic
override
getBool(String key) bool
override
getDouble(String key) double?
override
getInt(String key) int?
override
getKeys() Set<String>
override
getString(String key) String?
override
getStringList(String key) List<String>?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reload() Future<void>
override
remove(String key) Future<bool>
override
setBool(String key, bool value) Future<bool>
override
setDouble(String key, double value) Future<bool>
override
setInt(String key, int value) Future<bool>
override
setString(String key, String value) Future<bool>
override
setStringList(String key, List<String> value) Future<bool>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited